/*
   ODBCPrivate.h
   Copyright (c) 1996, NeXT Software, Inc.
   All rights reserved.
*/

#import <ODBCEOAdaptor/ODBCAdaptor.h>
#import <ODBCEOAdaptor/ODBCContext.h>
#import <ODBCEOAdaptor/ODBCChannel.h>
#import <ODBCEOAdaptor/ODBCColumn.h>
#import <ODBCEOAdaptor/ODBCSQLExpression.h>

// ODBC headers are not self contained: you need to include windows.h
// before. Since the only type used is the window handle (HWND) we
// just fake it right here. By doing so, we avoid dependencies and
// Makefile problems.
//
#define HWND void *

// This import is specific to ODBC on the solaris platform. uncomment if you need it.
// #import "sqlcli1.h"

#import "sql.h"
#import "sqlext.h"

// DB2 include file do not define SQL_TYPE_NULL
#ifndef SQL_TYPE_NULL
#define SQL_TYPE_NULL 0
#endif

@interface ODBCContext(_ODBCErrorNotification)
- (NSArray *)odbcErrorWithChannel:(ODBCChannel *)channel string:(NSString *)location raise:(BOOL)flag;
    // Returns an array of SQLState strings.

- (NSString *)odbcConnectWithWindowsHandle:(void *)windowHandle;
    // Popup the standard ODBC login panel and returns a new connection string
@end

@interface ODBCAdaptor(_ODBCPrivate)
- (EOAttribute *)attributeWithName:(NSString *)name columnName:(NSString *)columnName externalType:(NSString *)externalType odbcType:(int)odbcType length:(int)length precision:(int)precision scale:(int)scale nullable:(BOOL)nullable;
@end

@interface EOAttribute(_ODBCPrivate)
- (int)odbcType;
- (NSString *)odbcTypeString;
@end

//
// These are some useful private EOF methods.
// All these methods are trivial to implement.
// These are subject to change in future releases of EOF so
// use them with care.
//
@interface EOEntity (_ODBCPrivate)
- (EOAttribute *)attributeForPath:(NSString *)attributePath;
- (EORelationship *)relationshipForPath:(NSString *)relationshipPath;
@end

@interface NSString (_ODBCPrivate)
- (NSString *)relationshipPathByDeletingLastComponent;
@end

@interface EOSQLExpression (_ODBCPrivate)
- (NSString *)_aliasForRelatedAttribute:(EOAttribute *)attribute relationshipPath:(NSString *)relationshipPath;
@end


